# Constraint Utilities

## Index Generation
::: fdtdx.constraints.utils.compute_allowed_indices
::: fdtdx.constraints.utils.compute_allowed_indices_without_holes
::: fdtdx.constraints.utils.compute_allowed_indices_without_holes_single_polymer_columns

## Value Matching
::: fdtdx.constraints.utils.nearest_index
